@@ -39,12 +39,15 @@ __date__      = "$Date$"
 __copyright__ = "Copyright (c) 2005-2009 Sun Microsystems Inc."
 __license__   = "LGPL"
 
+import pyatspi
+
 import braille_generator
 import debug
 import flat_review
 import formatting
 import keybindings
 import orca_state
+import script_utilities
 import settings
 import speech_generator
 import structural_navigation
@@ -79,11 +82,17 @@ class Script:
         #
         self.presentIfInactive = True
 
+        self.utilities = self.getUtilities()
         self.structuralNavigation = self.getStructuralNavigation()
+        self.chat = self.getChat()
         self.inputEventHandlers = {}
         self.pointOfReference = {}
         self.setupInputEventHandlers()
         self.keyBindings = self.getKeyBindings()
+        if settings.validateKeyBindings:
+            validation = self.keyBindings.validate()
+            if len(validation):
+                debug.println(debug.LEVEL_SEVERE, validation)
         self.brailleBindings = self.getBrailleBindings()
         self.app_pronunciation_dict = self.getPronunciations()
 
@@ -200,6 +209,16 @@ class Script:
         """
         return tutorialgenerator.TutorialGenerator(self)
 
+    def getChat(self):
+        """Returns the 'chat' class for this script.
+        """
+        return None
+
+    def getUtilities(self):
+        """Returns the utilites for this script.
+        """
+        return script_utilities.Utilities(self)
+
     def getEnabledStructuralNavigationTypes(self):
         """Returns a list of the structural navigation object types
         enabled in this script.
@@ -337,6 +356,10 @@ class Script:
         #
         processEvent = (orca_state.activeScript == self \
                         or self.presentIfInactive)
+        if event.source.getRole() == pyatspi.ROLE_PROGRESS_BAR \
+           and not processEvent \
+           and settings.progressBarVerbosity == settings.PROGRESS_BAR_ALL:
+            processEvent = True
 
         if not processEvent:
             return
@@ -359,6 +382,27 @@ class Script:
             if event.type.startswith(key):
                 self.listeners[key](event)
 
+    def checkKeyboardEventData(self, keyboardEvent):
+        """Checks the data on the keyboard event.
+
+        Some toolkits don't fill all the key event fields, and/or fills
+        them out with unexpected data. This method tries to fill in the
+        missing fields and validate/standardize the data we've been given.
+        While any script can override this method, it is expected that
+        this will only be done at the toolkit script level.
+
+        Arguments:
+        - keyboardEvent: an instance of input_event.KeyboardEvent
+        """
+
+        try:
+            import gtk.gdk as gdk
+            keyboardEvent.keyval_name = gdk.keyval_name(keyboardEvent.id)
+        except:
+            debug.println(debug.LEVEL_FINE,
+                          "Could not obtain keyval_name for id: %d" \
+                          % keyboardEvent.id)
+
     def consumesKeyboardEvent(self, keyboardEvent):
         """Called when a key is pressed on the keyboard.
 
