@@ -17,8 +17,7 @@
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
 
-""" Custom script for Thunderbird 3.
-"""
+""" Custom script for Thunderbird 3."""
 
 __id__        = "$Id$"
 __version__   = "$Revision$"
@@ -40,7 +39,9 @@ import orca.scripts.toolkits.Gecko as Gecko
 
 from orca.orca_i18n import _
 
+from formatting import Formatting
 from speech_generator import SpeechGenerator
+from script_utilities import Utilities
 import script_settings
 
 ########################################################################
@@ -85,11 +86,20 @@ class Script(Gecko.Script):
 
         self.textArea = None
 
+    def getFormatting(self):
+        """Returns the formatting strings for this script."""
+        return Formatting(self)
+
     def getSpeechGenerator(self):
-        """Returns the speech generator for this script.
-        """
+        """Returns the speech generator for this script."""
+
         return SpeechGenerator(self)
 
+    def getUtilities(self):
+        """Returns the utilites for this script."""
+
+        return Utilities(self)
+
     def getAppPreferencesGUI(self):
         """Return a GtkVBox contain the application unique configuration
         GUI items for the current application.
@@ -133,8 +143,8 @@ class Script(Gecko.Script):
         script_settings.grabFocusOnAncestor = value
 
     def _debug(self, msg):
-        """ Convenience method for printing debug messages
-        """
+        """ Convenience method for printing debug messages"""
+
         debug.println(self.debugLevel, "Thunderbird.py: "+msg)
 
     def _isSpellCheckListItemFocus(self, event):
@@ -152,7 +162,7 @@ class Script(Gecko.Script):
                      pyatspi.ROLE_LIST, \
                      pyatspi.ROLE_DIALOG, \
                      pyatspi.ROLE_APPLICATION]
-        if self.isDesiredFocusedItem(event.source, rolesList):
+        if self.utilities.hasMatchingHierarchy(event.source, rolesList):
             dialog = event.source.parent.parent
 
             # Translators: this is what the name of the spell checking
@@ -237,7 +247,7 @@ class Script(Gecko.Script):
         """
         obj = event.source
         parent = obj.parent
-        top = self.getTopLevel(obj)
+        top = self.utilities.topLevelObject(obj)
         consume = False
 
         # Clear the stored autocomplete string.
@@ -258,7 +268,7 @@ class Script(Gecko.Script):
         #
         if obj.getRole() == pyatspi.ROLE_TABLE_CELL:
             table = parent.queryTable()
-            row = table.getRowAtIndex(self.getCellIndex(obj))
+            row = table.getRowAtIndex(self.utilities.cellIndex(obj))
             for i in range(0, table.nColumns):
                 acc = table.getAccessibleAt(row, i)
                 if acc.name:
@@ -288,7 +298,7 @@ class Script(Gecko.Script):
                      pyatspi.ROLE_INTERNAL_FRAME,
                      pyatspi.ROLE_FRAME,
                      pyatspi.ROLE_APPLICATION]
-        if self.isDesiredFocusedItem(event.source, rolesList):
+        if self.utilities.hasMatchingHierarchy(event.source, rolesList):
             self._debug("onFocus - message text area.")
 
             self.textArea = event.source
@@ -303,7 +313,7 @@ class Script(Gecko.Script):
             rolesList = [pyatspi.ROLE_ENTRY, \
                          pyatspi.ROLE_DIALOG, \
                          pyatspi.ROLE_APPLICATION]
-            if self.isDesiredFocusedItem(obj, rolesList):
+            if self.utilities.hasMatchingHierarchy(obj, rolesList):
                 dialog = obj.parent
 
                 # Translators: this is what the name of the spell checking
@@ -388,8 +398,9 @@ class Script(Gecko.Script):
                      pyatspi.ROLE_TREE_TABLE,
                      pyatspi.ROLE_SCROLL_PANE,
                      pyatspi.ROLE_SCROLL_PANE]
-        if self.isDesiredFocusedItem(event.source, rolesList):
-            if isinstance(orca_state.lastInputEvent, input_event.KeyboardEvent):
+        if self.utilities.hasMatchingHierarchy(event.source, rolesList):
+            if isinstance(orca_state.lastInputEvent, input_event.KeyboardEvent)\
+               and orca_state.lastNonModifierKeyEvent:
                 string = orca_state.lastNonModifierKeyEvent.event_string
                 if string == "Delete":
                     oldLocusOfFocus = None
@@ -402,7 +413,7 @@ class Script(Gecko.Script):
                      pyatspi.ROLE_INTERNAL_FRAME, \
                      pyatspi.ROLE_FRAME, \
                      pyatspi.ROLE_APPLICATION]
-        if self.isDesiredFocusedItem(event.source, rolesList):
+        if self.utilities.hasMatchingHierarchy(event.source, rolesList):
             if isinstance(orca_state.lastInputEvent, input_event.KeyboardEvent):
                 string = orca_state.lastNonModifierKeyEvent.event_string
                 if string == "Delete":
@@ -510,7 +521,7 @@ class Script(Gecko.Script):
                      pyatspi.ROLE_INTERNAL_FRAME, \
                      pyatspi.ROLE_FRAME, \
                      pyatspi.ROLE_APPLICATION]
-        if self.isDesiredFocusedItem(event.source, rolesList):
+        if self.utilities.hasMatchingHierarchy(event.source, rolesList):
             if isinstance(orca_state.lastInputEvent, input_event.KeyboardEvent):
                 string = orca_state.lastNonModifierKeyEvent.event_string
                 if string == "Delete":
@@ -529,7 +540,7 @@ class Script(Gecko.Script):
                      pyatspi.ROLE_LIST, \
                      pyatspi.ROLE_DIALOG, \
                      pyatspi.ROLE_APPLICATION]
-        if self.isDesiredFocusedItem(obj, rolesList):
+        if self.utilities.hasMatchingHierarchy(obj, rolesList):
             dialog = obj.parent.parent
 
             # Translators: this is what the name of the spell checking 
@@ -539,7 +550,7 @@ class Script(Gecko.Script):
             #
             if dialog.name.startswith(_("Check Spelling")):
                 if obj.getIndexInParent() == 0:
-                    badWord = self.getDisplayedText(dialog[1])
+                    badWord = self.utilities.displayedText(dialog[1])
 
                     if self.textArea != None:
                         # If we have a handle to the Thunderbird message text
@@ -547,7 +558,7 @@ class Script(Gecko.Script):
                         # create a list of all the words found in them.
                         #
                         allTokens = []
-                        text = self.getText(self.textArea, 0, -1)
+                        text = self.utilities.substring(self.textArea, 0, -1)
                         tokens = text.split()
                         allTokens += tokens
                         self.speakMisspeltWord(allTokens, badWord)
@@ -608,6 +619,17 @@ class Script(Gecko.Script):
             self.sayAll(None)
         self._messageLoaded = False
 
+    def sayCharacter(self, obj):
+        """Speaks the character at the current caret position."""
+
+        if self.isEditableMessage(obj):
+            text = self.utilities.queryNonEmptyText(obj)
+            if text and text.caretOffset + 1 >= text.characterCount:
+                default.Script.sayCharacter(self, obj)
+                return
+
+        Gecko.Script.sayCharacter(self, obj)
+
     def getBottomOfFile(self):
         """Returns the object and last caret offset at the bottom of the
         document frame. Overridden here to handle editable messages.
@@ -624,24 +646,6 @@ class Script(Gecko.Script):
 
         return [obj, offset]
 
-    def getDocumentFrame(self):
-        """Returns the document frame that holds the content being shown.
-        Overridden here because multiple open messages are not arranged
-        in tabs like they are in Firefox."""
-
-        if self.inFindToolbar():
-            return Gecko.Script.getDocumentFrame(self)
-
-        obj = orca_state.locusOfFocus
-        while obj:
-            role = obj.getRole()
-            if role in [pyatspi.ROLE_DOCUMENT_FRAME, pyatspi.ROLE_EMBEDDED]:
-                return obj
-            else:
-                obj = obj.parent
-
-        return None
-
     def toggleFlatReviewMode(self, inputEvent=None):
         """Toggles between flat review mode and focus tracking mode."""
 
@@ -659,9 +663,8 @@ class Script(Gecko.Script):
         Returns True is this is something like the Subject: entry
         """
         result = obj and obj.getRole() == pyatspi.ROLE_ENTRY \
-            and None == self.getAncestor(obj,
-                                         [pyatspi.ROLE_DOCUMENT_FRAME],
-                                         [pyatspi.ROLE_FRAME])
+            and not self.utilities.ancestorWithRole(
+                obj, [pyatspi.ROLE_DOCUMENT_FRAME], [pyatspi.ROLE_FRAME])
         return result
 
     def isEditableMessage(self, obj):
